==> nextcloud-app-mail-0.7.9-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/ru.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Почта",
    "Loading accounts" : "Загрузка учётных записей",
    "Error while loading the accounts." : "Ошибка загрузки учётных записей.",
    "Error while loading the selected account." : "Ошибка загрузки выбранного аккаунта.",
    "Can not load this folder." : "Невозможно загрузить эту папку.",
    "Searching for {query}" : "Поиск {query}",
    "Error while deleting message." : "Ошибка при удалении сообщения.",
    "Forwarded message" : "Пересланное сообщение",
    "Choose a folder to store the attachment in" : "Выберите каталог для хранения вложений",
    "Attachments saved to Files." : "Вложения сохранены в файлах.",
    "Attachment saved to Files." : "Вложение сохранено в файлах.",
    "Error while saving attachments to Files." : "Ошибка сохранения вложений в файлах.",
    "Error while saving attachment to Files." : "Ошибка сохранения вложения в файлах.",
    "Message flag could not be set." : "Не удалось установить флажок сообщения.",
    "Could not move message." : "Невозможно переместить сообщение.",
    "Invalid account" : "Неверная учётная запись",
    "Invalid folder" : "Неверная папка",
    "Error while creating the account: " : "Ошибка создания учётной записи:",
    "Unknown error" : "Неизвестная ошибка",
    "Error while updating the account: " : "Ошибка обновления учётной записи:",
    "All inboxes" : "Все входящие",
    "you" : "вы",
    "Send message to {email}" : "Отправить сообщения на {email}",
    "Could not load {tag}{name}{endtag}" : "Не удалось загрузить {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Проблема при загрузке {tag}{name}{endtag}",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n новое сообщение \nот {from}","%n новых сообщения \nот {from}","%n новых сообщений \nот {from}","%n новых сообщений \nот {from}"],
    "Nextcloud Mail" : "Почта Nextcloud",
    "Save" : "Сохранить",
    "Saved" : "Сохранено",
    "Show all folders" : "Показать все папки",
    "Collapse folders" : "Свернуть папки",
    "Error while deleting account." : "Ошибка удаления учётной записи.",
    "Choose a file to add as attachment" : "Выбрать файл для вложения",
    "An error occurred while uploading {fname}" : "При загрузке {fname} произошла ошибка",
    "Reply" : "Ответить",
    "Send" : "Отправить",
    "Sending …" : "Отправка...",
    "Message sent!" : "Сообщение отправлено!",
    "Server error" : "Ошибка сервера",
    "An unknown error occurred" : "Произошла неизвестная ошибка",
    "Opening HTML drafts is not supported yet." : "Работа с черновиками HTML пока не поддерживается.",
    "Draft saved!" : "Черновик сохранен!",
    "No writable calendars found" : "Календари доступные для записи не найдены",
    "Error while importing the calendar event" : "Ошибка при импорте календарного события",
    "Error while downloading calendar event" : "Ошибка при скачивании календарного события",
    "& others" : "и другие",
    "Error while loading messages." : "Ошибка пр загрузке изображений.",
    "Error while refreshing messages." : "Ошибка обновления списка писем.",
    "Setting up your account" : "Настраивается учётная запись",
    "Inbox" : "Входящие",
    "Sent" : "Отправленные",
    "Drafts" : "Черновики",
    "Archive" : "Архив",
    "Trash" : "Корзина",
    "Junk" : "Спам",
    "All" : "Все",
    "Favorites" : "Избранное",
    "Auto detect failed. Please use manual mode." : "Не удалось автоматически определить настройки. Воспользуйтесь ручным режимом.",
    "Updating account failed: " : "Ошибка обновления учётной записи:",
    "Creating account failed: " : "Ошибка создания учетной записи:",
    "Delete permanently" : "Удалить окончательно",
    "Error loading message" : "Ошибка загрузки сообщения",
    "Settings" : "Настройки",
    "Forwarding to %s" : "Пересылка на %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Нажмите здесь, если не запустилось автоматическое перенаправление в течение нескольких секунд.",
    "Redirect" : "Перенаправление",
    "The link leads to %s" : "Эта ссылка ведёт на %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Если вы не хотите посещать эту страницу, вы можете вернуться в <a href=\"%s\">Почту</a>.",
    "Continue to %s" : "Продолжать %s",
    "Delete account" : "Удалить учётную запись",
    "Try again" : "Попытаться снова",
    "New message" : "Создать сообщение",
    "Account Settings" : "Настройки учётной записи",
    "Aliases" : "Псевдонимы",
    "Mail address" : "Почтовый адрес",
    "Display Name" : "Отображаемое имя",
    "Account" : "Учётная запись",
    "Keyboard shortcuts" : "Комбинации клавиш",
    "Speed up your Mail experience with these quick shortcuts." : "Ускорьте работу с почтой использованием этих комбинаций клавиш.",
    "Compose new message" : "Создать новое сообщение",
    "Newer message" : "Самое новое сообщение",
    "Older message" : "Самое старое сообщение",
    "Toggle star" : "Переключить отметку звёздочкой",
    "Toggle unread" : "Переключить отметку прочтения",
    "Delete" : "Удалить",
    "Search" : "Поиск",
    "Refresh" : "Обновить",
    "Connect your mail account" : "Подключить почтовый аккаунт",
    "Name" : "Имя",
    "Mail Address" : "E-mail адрес",
    "Password" : "Пароль",
    "Manual configuration" : "Ручная настройка",
    "IMAP Host" : "IMAP-сервер",
    "IMAP security" : "Безопасность IMAP",
    "None" : "Отсутствует",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "порт IMAP",
    "IMAP User" : "IMAP-пользователь",
    "IMAP Password" : "пароль IMAP",
    "SMTP Host" : "сервер SMTP",
    "SMTP security" : "безопасность SMTP",
    "SMTP Port" : "порт SMTP",
    "SMTP User" : "пользователь SMTP",
    "SMTP Password" : "пароль SMTP",
    "Connect" : "Соединить",
    "from" : "от",
    "to" : "кому",
    "cc" : "копия",
    "bcc" : "скрытая копия",
    "Subject" : "Тема",
    "Save all to Files" : "Сохранить все в файлы",
    "Add mail account" : "Добавить почтовую учётную запись",
    "Use Gravatar and favicon avatars" : "Использовать значки Gravatar и favicon",
    "No search results for" : "Ничего не найдено для",
    "The images have been blocked to protect your privacy." : "Изображения были заблокированы для защиты вашей частной жизни.",
    "Show images from this sender" : "Показать изображения от этого отправителя",
    "Forward" : "Переслать",
    "No messages in this folder!" : "В этой папке нет сообщений!",
    "Upload attachment" : "Загрузить вложение",
    "Add attachment from Files" : "Выбрать вложение из файлов",
    "Import into calendar" : "Импортировать в календарь",
    "Download attachment" : "Скачать вложение",
    "Save to Files" : "Сохранить в файлы"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");

==> nextcloud-app-mail-0.7.10-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/ru.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Почта",
    "Loading accounts" : "Загрузка учётных записей",
    "Error while loading the accounts." : "Ошибка загрузки учётных записей.",
    "Error while loading the selected account." : "Ошибка загрузки выбранного аккаунта.",
    "Can not load this folder." : "Невозможно загрузить эту папку.",
    "Searching for {query}" : "Поиск {query}",
    "Error while deleting message." : "Ошибка при удалении сообщения.",
    "Forwarded message" : "Пересланное сообщение",
    "Choose a folder to store the attachment in" : "Выберите каталог для хранения вложений",
    "Attachments saved to Files." : "Вложения сохранены в файлах.",
    "Attachment saved to Files." : "Вложение сохранено в файлах.",
    "Error while saving attachments to Files." : "Ошибка сохранения вложений в файлах.",
    "Error while saving attachment to Files." : "Ошибка сохранения вложения в файлах.",
    "Message flag could not be set." : "Не удалось установить флажок сообщения.",
    "Could not move message." : "Невозможно переместить сообщение.",
    "Invalid account" : "Неверная учётная запись",
    "Invalid folder" : "Неверная папка",
    "Error while creating the account: " : "Ошибка создания учётной записи:",
    "Unknown error" : "Неизвестная ошибка",
    "Error while updating the account: " : "Ошибка обновления учётной записи:",
    "All inboxes" : "Все входящие",
    "you" : "вы",
    "Send message to {email}" : "Отправить сообщения на {email}",
    "Could not load {tag}{name}{endtag}" : "Не удалось загрузить {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Проблема при загрузке {tag}{name}{endtag}",
    "Could not load your message" : "Ошибка получения вашего сообщения",
    "Could not load the desired message" : "Ошибка получения указанного сообщения",
    "Could not load the message" : "Ошибка получения этого сообщения",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n новое сообщение \nот {from}","%n новых сообщения \nот {from}","%n новых сообщений \nот {from}","%n новых сообщений \nот {from}"],
    "Nextcloud Mail" : "Почта Nextcloud",
    "Save" : "Сохранить",
    "Saved" : "Сохранено",
    "Show all folders" : "Показать все папки",
    "Collapse folders" : "Свернуть папки",
    "Error while deleting account." : "Ошибка удаления учётной записи.",
    "Choose a file to add as attachment" : "Выбрать файл для вложения",
    "An error occurred while uploading {fname}" : "При загрузке {fname} произошла ошибка",
    "Reply" : "Ответить",
    "Send" : "Отправить",
    "Sending …" : "Отправка...",
    "Message sent!" : "Сообщение отправлено!",
    "Server error" : "Ошибка сервера",
    "An unknown error occurred" : "Произошла неизвестная ошибка",
    "Opening HTML drafts is not supported yet." : "Работа с черновиками HTML пока не поддерживается.",
    "No writable calendars found" : "Календари доступные для записи не найдены",
    "Error while importing the calendar event" : "Ошибка при импорте календарного события",
    "Error while downloading calendar event" : "Ошибка при скачивании календарного события",
    "& others" : "и другие",
    "Error while loading messages." : "Ошибка пр загрузке изображений.",
    "Error while refreshing messages." : "Ошибка обновления списка писем.",
    "Setting up your account" : "Настраивается учётная запись",
    "Inbox" : "Входящие",
    "Sent" : "Отправленные",
    "Drafts" : "Черновики",
    "Archive" : "Архив",
    "Trash" : "Корзина",
    "Junk" : "Спам",
    "All" : "Все",
    "Favorites" : "Избранное",
    "Auto detect failed. Please use manual mode." : "Не удалось автоматически определить настройки. Воспользуйтесь ручным режимом.",
    "Updating account failed: " : "Ошибка обновления учётной записи:",
    "Creating account failed: " : "Ошибка создания учетной записи:",
    "Delete permanently" : "Удалить окончательно",
    "Error loading message" : "Ошибка загрузки сообщения",
    "Settings" : "Настройки",
    "Forwarding to %s" : "Пересылка на %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Нажмите здесь, если не запустилось автоматическое перенаправление в течение нескольких секунд.",
    "Redirect" : "Перенаправление",
    "The link leads to %s" : "Эта ссылка ведёт на %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Если вы не хотите посещать эту страницу, вы можете вернуться в <a href=\"%s\">Почту</a>.",
    "Continue to %s" : "Продолжать %s",
    "Delete account" : "Удалить учётную запись",
    "Try again" : "Попытаться снова",
    "New message" : "Создать сообщение",
    "Account Settings" : "Настройки учётной записи",
    "Aliases" : "Псевдонимы",
    "Mail address" : "Почтовый адрес",
    "Display Name" : "Отображаемое имя",
    "Account" : "Учётная запись",
    "Keyboard shortcuts" : "Комбинации клавиш",
    "Speed up your Mail experience with these quick shortcuts." : "Ускорьте работу с почтой использованием этих комбинаций клавиш.",
    "Compose new message" : "Создать новое сообщение",
    "Newer message" : "Самое новое сообщение",
    "Older message" : "Самое старое сообщение",
    "Toggle star" : "Переключить отметку звёздочкой",
    "Toggle unread" : "Переключить отметку прочтения",
    "Delete" : "Удалить",
    "Search" : "Поиск",
    "Refresh" : "Обновить",
    "Connect your mail account" : "Подключить почтовый аккаунт",
    "Name" : "Имя",
    "Mail Address" : "E-mail адрес",
    "Password" : "Пароль",
    "Manual configuration" : "Ручная настройка",
    "IMAP Host" : "IMAP-сервер",
    "IMAP security" : "Безопасность IMAP",
    "None" : "Отсутствует",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "порт IMAP",
    "IMAP User" : "IMAP-пользователь",
    "IMAP Password" : "пароль IMAP",
    "SMTP Host" : "сервер SMTP",
    "SMTP security" : "безопасность SMTP",
    "SMTP Port" : "порт SMTP",
    "SMTP User" : "пользователь SMTP",
    "SMTP Password" : "пароль SMTP",
    "Connect" : "Соединить",
    "from" : "от",
    "to" : "кому",
    "cc" : "копия",
    "bcc" : "скрытая копия",
    "Note that the mail came from a noreply address so your reply will probably not be read." : "Предупреждение: сообщение было отправлено с адреса, не предусматривающего получения ответов. Ваше сообщение, направленное на этот адрес, возможно никогда не будет прочитано.",
    "Subject" : "Тема",
    "Save all to Files" : "Сохранить все в файлы",
    "Add mail account" : "Добавить почтовую учётную запись",
    "Use Gravatar and favicon avatars" : "Использовать значки Gravatar и favicon",
    "No search results for" : "Ничего не найдено для",
    "The images have been blocked to protect your privacy." : "Изображения были заблокированы для защиты вашей частной жизни.",
    "Show images from this sender" : "Показать изображения от этого отправителя",
    "Forward" : "Переслать",
    "No messages in this folder!" : "В этой папке нет сообщений!",
    "Upload attachment" : "Загрузить вложение",
    "Add attachment from Files" : "Выбрать вложение из файлов",
    "Import into calendar" : "Импортировать в календарь",
    "Download attachment" : "Скачать вложение",
    "Save to Files" : "Сохранить в файлы"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
